@@ -1,6 +1,6 @@
 from collections import defaultdict
 
-from django.db import models
+from django.db.models import get_model
 from django.db.models import Q
 from django.contrib.contenttypes.models import ContentType
 
@@ -63,14 +63,14 @@ class ActionManager(GFKManager):
         Stream of most recent actions by objects that the passed User object is
         following.
         """
-        from actstream.models import Follow
         q = Q()
         qs = self.filter(public=True)
         actors_by_content_type = defaultdict(lambda: [])
         others_by_content_type = defaultdict(lambda: [])
 
-        follow_gfks = Follow.objects.filter(user=object).values_list(
-            'content_type_id', 'object_id', 'actor_only')
+        follow_gfks = get_model('actstream', 'follow').objects.filter(
+            user=object).values_list('content_type_id',
+                                     'object_id', 'actor_only')
 
         if not follow_gfks:
             return qs.none()
@@ -97,7 +97,7 @@ class ActionManager(GFKManager):
         return qs
 
 
-class FollowManager(models.Manager):
+class FollowManager(GFKManager):
     """
     Manager for Follow model.
     """
@@ -117,3 +117,25 @@ class FollowManager(models.Manager):
             return False
         queryset = self.for_object(instance)
         return queryset.filter(user=user).exists()
+
+    def followers(self, actor):
+        """
+        Returns a list of User objects who are following the given actor (eg my followers).
+        """
+        return [follow.user for follow in self.filter(
+            content_type=ContentType.objects.get_for_model(actor),
+            object_id=actor.pk
+        ).select_related('user')]
+
+    def following(self, user, *models):
+        """
+        Returns a list of actors that the given user is following (eg who im following).
+        Items in the list can be of any model unless a list of restricted models are passed.
+        Eg following(user, User) will only return users following the given user
+        """
+        qs = self.filter(user=user)
+        if len(models):
+            qs = qs.filter(content_type__in=(
+                ContentType.objects.get_for_model(model) for model in models)
+            )
+        return [follow.follow_object for follow in qs.fetch_generic_relations()]
