@@ -5,7 +5,6 @@ from django.utils.translation import ugettext as _
 
 from django.contrib.contenttypes import generic
 from django.contrib.contenttypes.models import ContentType
-from django.contrib.auth.models import User
 
 try:
     from django.utils import timezone
@@ -18,6 +17,10 @@ from actstream import settings as actstream_settings
 from actstream.signals import action
 from actstream.actions import action_handler
 from actstream.managers import FollowManager
+from actstream.compat import user_model_label
+
+User = user_model_label
+
 
 class Follow(models.Model):
     """
@@ -157,6 +160,7 @@ model_stream = Action.objects.model_actions
 followers = Follow.objects.followers
 following = Follow.objects.following
 
+
 def setup_generic_relations():
     """
     Set up GenericRelations for actionable models.
@@ -165,12 +169,16 @@ def setup_generic_relations():
         if not model:
             continue
         for field in ('actor', 'target', 'action_object'):
+            attr = '%s_actions' % field
+            if isinstance(getattr(model, attr, None),
+                          generic.ReverseGenericRelatedObjectsDescriptor):
+                break
             generic.GenericRelation(Action,
                 content_type_field='%s_content_type' % field,
                 object_id_field='%s_object_id' % field,
                 related_name='actions_with_%s_%s_as_%s' % (
                     model._meta.app_label, model._meta.module_name, field),
-            ).contribute_to_class(model, '%s_actions' % field)
+            ).contribute_to_class(model, attr)
 
             # @@@ I'm not entirely sure why this works
             setattr(Action, 'actions_with_%s_%s_as_%s' % (
@@ -184,7 +192,7 @@ if actstream_settings.USE_JSONFIELD:
     try:
         from jsonfield.fields import JSONField
     except ImportError:
-        raise ImproperlyConfigured('You must have django-extensions installed '
+        raise ImproperlyConfigured('You must have django-jsonfield installed '
                                 'if you wish to use a JSONField on your actions')
     JSONField(blank=True, null=True).contribute_to_class(Action, 'data')
 
